@@ -27,7 +27,7 @@ class RTMP(VideoRetriever):
         if file_d is None:
             return
         args += ["-o", self.options.output]
-        if self.options.silent or self.options.output == "-":
+        if self.options.silent:
             args.append("-q")
         if self.options.other:
             if is_py2:
@@ -39,12 +39,10 @@ class RTMP(VideoRetriever):
             args.append("-V")
 
         command = ["rtmpdump", "-r", self.url] + args
-        log.debug("Running: %s", " ".join(command))
+        log.debug("Running: {0}".format(" ".join(command)))
         try:
             subprocess.call(command)
         except OSError as e:
-            log.error("Could not execute rtmpdump: " + e.strerror)
+            log.error("Could not execute rtmpdump: {0}".format(e.strerror))
             return
         self.finished = True
-
-
