@@ -5,7 +5,6 @@ import sys
 import time
 import re
 import os
-import io
 import platform
 from datetime import timedelta
 
@@ -106,7 +105,7 @@ def progressbar(total, pos, msg=""):
     function.
     """
     width = get_terminal_size()[0] - 40
-    rel_pos = int(float(pos)/total*width)
+    rel_pos = int(float(pos) / total * width)
     bar = ''.join(["=" * rel_pos, "." * (width - rel_pos)])
 
     # Determine how many digits in total (base 10)
@@ -142,51 +141,42 @@ def filename(stream):
 
 
 def output(options, extension="mp4", openfd=True, mode="wb", **kwargs):
-    subtitlefiles = ["srt", "smi", "tt","sami", "wrst"]
-    if is_py2:
-        file_d = file
-    else:
-        file_d = io.IOBase
+    subtitlefiles = ["srt", "smi", "tt", "sami", "wrst"]
 
-    if options.output != "-":
-        ext = re.search(r"(\.\w{2,4})$", options.output)
-        if not ext:
-            options.output = "%s.%s" % (options.output, extension)
-        if options.output_auto and ext:
-            options.output = "%s.%s" % (options.output, extension)
-        elif extension == "srt" and ext:
-            options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
-        if ext and extension == "srt" and ext.group(1).split(".")[-1] in subtitlefiles:
-            options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
-        log.info("Outfile: %s", options.output)
-        if os.path.isfile(options.output) or \
-                findexpisode(os.path.dirname(os.path.realpath(options.output)), options.service, os.path.basename(options.output)):
-            if extension in subtitlefiles:
-                if not options.force_subtitle:
-                    log.error("File (%s) already exists. Use --force-subtitle to overwrite" % options.output)
-                    return None
-            else:
-                if not options.force:
-                    log.error("File (%s) already exists. Use --force to overwrite" % options.output)
-                    return None
-        if openfd:
-            file_d = open(options.output, mode, **kwargs)
-    else:
-        if openfd:
-            if is_py2:
-                file_d = sys.stdout
-            else:
-                file_d = sys.stdout.buffer
-
-    return file_d
+    ext = re.search(r"(\.\w{2,4})$", options.output)
+    if not ext:
+        options.output = "%s.%s" % (options.output, extension)
+    if options.output_auto and ext:
+        options.output = "%s.%s" % (options.output, extension)
+    elif extension == "srt" and ext:
+        options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
+    if ext and extension == "srt" and ext.group(1).split(".")[-1] in subtitlefiles:
+        options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
+    log.info("Outfile: %s", options.output)
+    if os.path.isfile(options.output) or \
+            findexpisode(os.path.dirname(os.path.realpath(options.output)), options.service, os.path.basename(options.output)):
+        if extension in subtitlefiles:
+            if not options.force_subtitle:
+                if not (options.silent or options.silent_semi):
+                    log.warn("File (%s) already exists. Use --force-subtitle to overwrite" % options.output)
+                return None
+        else:
+            if not options.force:
+                if not (options.silent or options.silent_semi):
+                    log.warn("File (%s) already exists. Use --force to overwrite" % options.output)
+                return None
+    if openfd:
+        file_d = open(options.output, mode, **kwargs)
+        return file_d
+    return True
 
 
 def findexpisode(directory, service, name):
-    subtitlefiles = ["srt", "smi", "tt","sami", "wrst"]
+    subtitlefiles = ["srt", "smi", "tt", "sami", "wrst"]
     match = re.search(r"-(\w+)-\w+.(\w{2,3})$", name)
     if not match:
         return False
-    
+
     videoid = match.group(1)
     extension = match.group(2)
 
