@@ -1,16 +1,16 @@
 from json import dumps
 from random import sample
-import subprocess
 import os
 import platform
+import re
 from requests import post, codes, Timeout
 
 from svtplay_dl.log import log
-from svtplay_dl.utils import which, is_py3
+from svtplay_dl.utils import which, is_py3, run_program
 
 
 class postprocess(object):
-    def __init__(self, stream, options, subfixes = []):
+    def __init__(self, stream, options, subfixes=[]):
         self.stream = stream
         self.merge_subtitle = options.merge_subtitle
         self.external_subtitle = options.subtitle
@@ -42,9 +42,12 @@ class postprocess(object):
             random_sentences = ' '.join(sample(parse(self), 8)).replace('\r\n', '')
             url = 'https://whatlanguage.herokuapp.com'
             payload = {"query": random_sentences}
-            headers = {'content-type': 'application/json'} # Note: requests handles json from version 2.4.2 and onwards so i use json.dumps for now.
+            # Note: requests handles json from version 2.4.2 and onwards so i use json.dumps for now.
+            headers = {'content-type': 'application/json'}
             try:
-                r = post(url, data=dumps(payload), headers=headers, timeout=30) # Note: reasonable timeout i guess? svtplay-dl is mainly used while multitasking i presume, and it is heroku after all (fast enough)
+                # Note: reasonable timeout i guess? svtplay-dl is mainly used while multitasking i presume,
+                # and it is heroku after all (fast enough)
+                r = post(url, data=dumps(payload), headers=headers, timeout=30)
                 if r.status_code == codes.ok:
                     try:
                         response = r.json()
@@ -66,7 +69,8 @@ class postprocess(object):
         }
         if len(self.subfixes) >= 2:
             log.info("Determining the languages of the subtitles.")
-        else: log.info("Determining the language of the subtitle.")
+        else:
+            log.info("Determining the language of the subtitle.")
         if self.get_all_subtitles:
             from re import match
             for subfix in self.subfixes:
@@ -84,7 +88,8 @@ class postprocess(object):
             langs += [query(subfile)]
         if len(langs) >= 2:
             log.info("Language codes: " + ', '.join(langs))
-        else: log.info("Language code: " + langs[0])
+        else:
+            log.info("Language code: " + langs[0])
         return langs
 
     def remux(self):
@@ -99,21 +104,25 @@ class postprocess(object):
             name, ext = os.path.splitext(orig_filename)
             new_name = u"{0}.mp4".format(name)
 
+            cmd = [self.detect, "-i", orig_filename]
+            _, stdout, stderr = run_program(cmd, False) # return 1 is good here.
+            videotrack, audiotrack = self._checktracks(stderr)
+
             if self.merge_subtitle:
                 log.info(u"Muxing {0} and merging its subtitle into {1}".format(orig_filename, new_name))
             else:
                 log.info(u"Muxing {0} into {1}".format(orig_filename, new_name))
 
             tempfile = u"{0}.temp".format(orig_filename)
-            arguments = ["-map", "0:v", "-map", "0:a", "-c", "copy", "-copyts", "-f", "mp4"]
+            arguments = ["-map", "0:{}".format(videotrack), "-map", "0:{}".format(audiotrack), "-c", "copy", "-copyts", "-f", "mp4"]
             if ext == ".ts":
                 arguments += ["-bsf:a", "aac_adtstoasc"]
-            cmd = [self.detect, "-i", orig_filename]
 
             if self.merge_subtitle:
                 langs = self.sublanguage()
                 for stream_num, language in enumerate(langs):
-                    arguments += ["-map", str(stream_num + 1), "-c:s:" + str(stream_num), "mov_text", "-metadata:s:s:" + str(stream_num), "language=" + language]
+                    arguments += ["-map", str(stream_num + 1), "-c:s:" + str(stream_num), "mov_text",
+                                  "-metadata:s:s:" + str(stream_num), "language=" + language]
                 if len(self.subfixes) >= 2:
                     for subfix in self.subfixes:
                         subfile = "{0}.srt".format(name + subfix)
@@ -124,12 +133,8 @@ class postprocess(object):
 
             arguments += ["-y", tempfile]
             cmd += arguments
-            p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, stdin=subprocess.PIPE)
-            stdout, stderr = p.communicate()
-            if p.returncode != 0:
-                stderr = stderr.decode('utf-8', 'replace')
-                msg = stderr.strip().split('\n')[-1]
-                log.error("Something went wrong: {0}".format(msg))
+            returncode, stdout, stderr = run_program(cmd)
+            if returncode != 0:
                 return
 
             if self.merge_subtitle and not self.external_subtitle:
@@ -138,8 +143,10 @@ class postprocess(object):
                     for subfix in self.subfixes:
                         subfile = "{0}.srt".format(name + subfix)
                         os.remove(subfile)
-                else: os.remove(subfile)
-            else: log.info("Muxing done, removing the old file.")
+                else:
+                    os.remove(subfile)
+            else:
+                log.info("Muxing done, removing the old file.")
             os.remove(orig_filename)
             os.rename(tempfile, new_name)
 
@@ -151,21 +158,31 @@ class postprocess(object):
             return
 
         orig_filename = self.stream.options.output
+
+        cmd = [self.detect, "-i", orig_filename]
+        _, stdout, stderr = run_program(cmd, False)  # return 1 is good here.
+        videotrack, audiotrack = self._checktracks(stderr)
+
         if self.merge_subtitle:
             log.info("Merge audio, video and subtitle into {0}".format(orig_filename))
         else:
             log.info("Merge audio and video into {0}".format(orig_filename))
 
         tempfile = u"{0}.temp".format(orig_filename)
-        name = os.path.splitext(orig_filename)[0]
-        audio_filename = u"{0}.m4a".format(name)
+        name, ext = os.path.splitext(orig_filename)
         arguments = ["-c:v", "copy", "-c:a", "copy", "-f", "mp4"]
+        if ext == ".ts":
+            audio_filename = u"{0}.audio.ts".format(name)
+            arguments += ["-bsf:a", "aac_adtstoasc"]
+        else:
+            audio_filename = u"{0}.m4a".format(name)
         cmd = [self.detect, "-i", orig_filename, "-i", audio_filename]
 
         if self.merge_subtitle:
             langs = self.sublanguage()
-            for stream_num, language in enumerate(langs, start=2):
-                arguments += ["-map", "0", "-map", "1", "-map", str(stream_num), "-c:s:" + str(stream_num - 2), "mov_text", "-metadata:s:s:" + str(stream_num - 2), "language=" + language]
+            for stream_num, language in enumerate(langs, start=audiotrack + 1):
+                arguments += ["-map", "{}".format(videotrack), "-map", "{}".format(audiotrack), "-map", str(stream_num), "-c:s:" + str(stream_num - 2), "mov_text",
+                              "-metadata:s:s:" + str(stream_num - 2), "language=" + language]
             if len(self.subfixes) >= 2:
                 for subfix in self.subfixes:
                     subfile = "{0}.srt".format(name + subfix)
@@ -176,12 +193,8 @@ class postprocess(object):
 
         arguments += ["-y", tempfile]
         cmd += arguments
-        p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, stdin=subprocess.PIPE)
-        stdout, stderr = p.communicate()
-        if p.returncode != 0:
-            stderr = stderr.decode('utf-8', 'replace')
-            msg = stderr.strip().split('\n')[-1]
-            log.error("Something went wrong: {0}".format(msg))
+        returncode, stdout, stderr = run_program(cmd)
+        if returncode != 0:
             return
 
         log.info("Merging done, removing old files.")
@@ -192,5 +205,20 @@ class postprocess(object):
                 for subfix in self.subfixes:
                     subfile = "{0}.srt".format(name + subfix)
                     os.remove(subfile)
-            else: os.remove(subfile)
+            else:
+                os.remove(subfile)
         os.rename(tempfile, orig_filename)
+
+    def _checktracks(self, output):
+        allstuff = re.findall("Stream \#\d:(\d)\[[^\[]+\]: (Video|Audio): (.*)", output)
+        videotrack = 0
+        audiotrack = 1
+        for stream in allstuff:
+            if stream[1] == "Video":
+                videotrack = stream[0]
+            if stream[1] == "Audio":
+                if stream[2] == "mp3, 0 channels":
+                    continue
+                audiotrack = stream[0]
+
+        return videotrack, audiotrack
