@@ -24,17 +24,16 @@ class Bambuser(Service, OpenGraphThumbMixin):
             yield ServiceError("Excluding video")
             return
 
-        json_url = "http://player-c.api.bambuser.com/getVideo.json?api_key=005f64509e19a868399060af746a00aa&vid=%s" % match.group(1)
+        json_url = "http://player-c.api.bambuser.com/getVideo.json?api_key=005f64509e19a868399060af746a00aa&vid={0}".format(match.group(1))
         data = self.http.request("get", json_url).text
 
         info = json.loads(data)["result"]
         video = info["url"]
         if video[:4] == "rtmp":
-            playpath = info["id"][len(info["id"])-36:]
-            self.options.other = "-y %s" % playpath
+            playpath = info["id"][len(info["id"]) - 36:]
+            self.options.other = "-y {0}".format(playpath)
             if info["type"] == "live":
                 self.options.live = True
             yield RTMP(copy.copy(self.options), video, "0")
         else:
             yield HTTP(copy.copy(self.options), video, "0")
-
