@@ -1,4 +1,5 @@
 from __future__ import absolute_import
+from __future__ import unicode_literals
 import re
 import copy
 import os
@@ -8,28 +9,36 @@ from svtplay_dl.log import log
 from svtplay_dl.fetcher.dash import dashparse
 from svtplay_dl.subtitle import subtitle
 from svtplay_dl.utils import filenamify
-from svtplay_dl.utils.urllib import urljoin
+from svtplay_dl.utils.urllib import urljoin, urlparse
 from svtplay_dl.error import ServiceError
 
+
 class Cmore(Service):
-    supported_domains = ['www.cmore.se']
+    supported_domains = ['www.cmore.se', 'www.cmore.dk', 'www.cmore.no', 'www.cmore.fi']
 
     def get(self):
         if not self.options.username or not self.options.password:
             yield ServiceError("You need username and password to download things from this site.")
             return
+
         token, message = self._login()
         if not token:
             yield ServiceError(message)
             return
+
         res = self.http.get(self.url)
-        match = re.search('data-asset-splash-section data-asset-id="([^"]+)"', res.text)
+        match = re.search('data-asset-id="([^"]+)"', res.text)
         if not match:
             yield ServiceError("Can't find video id")
             return
-        url = "https://restapi.cmore.se/api/tve_web/asset/{0}/play.json?protocol=VUDASH".format(match.group(1))
+
+        tld = self._gettld()
+        url = "https://restapi.cmore.{0}/api/tve_web/asset/{1}/play.json?protocol=VUDASH".format(tld, match.group(1))
         res = self.http.get(url, headers={"authorization": "Bearer {0}".format(token)})
         janson = res.json()
+        if "error" in janson:
+            yield ServiceError("This video is geoblocked")
+            return
 
         if self.options.output_auto:
             directory = os.path.dirname(self.options.output)
@@ -38,7 +47,7 @@ class Cmore(Service):
             if basename is None:
                 yield ServiceError("Cant find vid id for autonaming")
                 return
-            title = "%s-%s-%s" % (basename, match.group(1), self.options.service)
+            title = "{0}-{1}-{2}".format(basename, match.group(1), self.options.service)
             title = filenamify(title)
             if len(directory):
                 self.options.output = os.path.join(directory, title)
@@ -72,13 +81,23 @@ class Cmore(Service):
                         yield streams[n]
 
     def _autoname(self, vid):
-        url = "https://restapi.cmore.se/api/tve_web/asset/{0}.json?expand=metadata".format(vid)
+        url = "https://restapi.cmore.{0}/api/tve_web/asset/{1}.json?expand=metadata".format(self._gettld(), vid)
         res = self.http.get(url)
         janson = res.json()["asset"]["metadata"]
         if isinstance(janson["title"], list):
             for i in janson["title"]:
-                if i["@xml:lang"] == "sv_SE": # if we add other .tld, we might need to change this.
-                    name = i["$"]
+                if self._gettld() == "se":
+                    if i["@xml:lang"] == "sv_SE":
+                        name = i["$"]
+                elif self._gettld() == "dk":
+                    if i["@xml:lang"] == "da_DK":
+                        name = i["$"]
+                elif self._gettld() == "no":
+                    if i["@xml:lang"] == "nb_NO":
+                        name = i["$"]
+                elif self._gettld() == "fi":
+                    if i["@xml:lang"] == "fi_FI":
+                        name = i["$"]
         else:
             name = janson["title"]["$"]
 
@@ -97,7 +116,7 @@ class Cmore(Service):
         res = self.http.get(self.url)
         tags = re.findall('<a class="card__link" href="([^"]+)"', res.text)
         for i in tags:
-            url = urljoin("https://www.cmore.se/", i)
+            url = urljoin("https://www.cmore.{}/".format(self._gettld()), i)
             if url not in episodes:
                 episodes.append(url)
 
@@ -105,19 +124,23 @@ class Cmore(Service):
             return sorted(episodes[-options.all_last:])
         return sorted(episodes)
 
+    def _gettld(self):
+        if isinstance(self.url, list):
+            parse = urlparse(self.url[0])
+        else:
+            parse = urlparse(self.url)
+        return re.search('\.(\w{2})$', parse.netloc).group(1)
+
     def _login(self):
-        url = "https://www.cmore.se/login"
+        tld = self._gettld()
+        url = "https://www.cmore.{}/login".format(tld)
         res = self.http.get(url, cookies=self.cookies)
         if self.options.cmoreoperator:
             post = {"username": self.options.username, "password": self.options.password,
-                    "operator": self.options.cmoreoperator, "country_code": "se"}
+                    "operator": self.options.cmoreoperator, "country_code": tld}
         else:
-            match = re.search('authenticity_token" value="([^"]+)"', res.text)
-            if not match:
-                return None, "Can't find authenticity_token needed to login"
-            post = {"username": self.options.username, "password": self.options.password, "authenticity_token": match.group(1),
-                    "redirect": "true"}
-        res = self.http.post("https://account.cmore.se/session?client=web", json=post, cookies=self.cookies)
+            post = {"username": self.options.username, "password": self.options.password}
+        res = self.http.post("https://account.cmore.{}/session?client=cmore-web-prod".format(tld), json=post, cookies=self.cookies)
         if res.status_code >= 400:
             return None, "Wrong username or password"
         janson = res.json()
@@ -125,9 +148,6 @@ class Cmore(Service):
         return token, None
 
     def operatorlist(self):
-        res = self.http.get("https://www.cmore.se/operator/login")
-        res.encoding = "utf-8"
-        match = re.findall('<option value="([^"]+)">([^"]+)</option>', res.text)
-        for i in match:
-            message = "operator: '{0}' value: '{1}'".format(i[1], i[0].replace("-", ""))
-            print(message)
+        res = self.http.get("https://tve.cmore.se/country/{0}/operator?client=cmore-web".format(self._gettld()))
+        for i in res.json()["data"]["operators"]:
+            print("operator: '{0}'".format(i["name"].lower()))
