@@ -32,11 +32,11 @@ class Hbo(Service):
         if not match:
             log.error("Cant find video file")
             return
-        url = "http://www.hbo.com/data/content/%s.xml" % match.group(1)
+        url = "http://www.hbo.com/data/content/{0}.xml".format(match.group(1))
         data = self.http.request("get", url).content
         xml = ET.XML(data)
         videoid = xml.find("content")[1].find("videoId").text
-        url = "http://render.cdn.hbo.com/data/content/global/videos/data/%s.xml" % videoid
+        url = "http://render.cdn.hbo.com/data/content/global/videos/data/{0}.xml".format(videoid)
         data = self.http.request("get", url).content
         xml = ET.XML(data)
         ss = xml.find("videos")
@@ -48,5 +48,5 @@ class Hbo(Service):
         for i in sa:
             videourl = i.find("tv14").find("path").text
             match = re.search("/([a-z0-9]+:[a-z0-9]+)/", videourl)
-            self.options.other = "-y %s" % videourl[videourl.index(match.group(1)):]
+            self.options.other = "-y {0}".format(videourl[videourl.index(match.group(1)):])
             yield RTMP(copy.copy(self.options), videourl[:videourl.index(match.group(1))], i.attrib["width"])
