@@ -38,5 +38,5 @@ class Mtvservices(Service):
 
         for i in sa:
             temp = i.find("src").text.index("gsp.comedystor")
-            url = "http://mtvnmobile.vo.llnwd.net/kip0/_pxn=0+_pxK=18639+_pxE=mp4/44620/mtvnorigin/%s" % i.find("src").text[temp:]
+            url = "http://mtvnmobile.vo.llnwd.net/kip0/_pxn=0+_pxK=18639+_pxE=mp4/44620/mtvnorigin/{0}".format(i.find("src").text[temp:])
             yield HTTP(copy.copy(self.options), url, i.attrib["height"])
