@@ -6,7 +6,6 @@ import json
 import copy
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.utils.urllib import urlparse
 from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
 from svtplay_dl.subtitle import subtitle
@@ -52,8 +51,9 @@ class Nrk(Service, OpenGraphThumbMixin):
             yield ServiceError("Can't fetch the video because of geoblocking")
             return
         streams = hlsparse(self.options, data, hlsurl)
-        for n in list(streams.keys()):
-            yield streams[n]
+        if streams:
+            for n in list(streams.keys()):
+                yield streams[n]
 
         streams = hdsparse(copy.copy(self.options), self.http.request("get", manifest_url, params={"hdcore": "3.7.0"}),
                            manifest_url)
